@@ -35,20 +35,24 @@ nsim <- 100
 var  <- .3   #sizeable
 
 set.seed(20)
-coxme.refine.debugswitch <- TRUE  
 fit1 <- coxme(Surv(time, status) ~ age + trt + (trt|inst) + strata(inst),
-              vfixed=.3, simdata, refine.n=nsim)
+              vfixed=.3, simdata, refine.n=nsim, refine.detail=TRUE)
 
-debug <- fit1$refine.debug  # Optional return item -see end of coxme.fit
+debug <- fit1$refine.detail 
 
-nfrail <- length(unlist(fit1$frail))
+nfrail <- length(unlist(ranef(fit1)))
+hmatbb <- fit1$hmat[1:nfrail, 1:nfrail]
+bhat <- unlist(ranef(fit1))  #random coefs
 set.seed(20)
+rdf <- coxme.control()$refine.df
 bmat <- matrix(rnorm(nfrail*nsim), nfrail)  # replicate the simulations
+bmat <- backsolve(hmatbb, bmat) /
+    rep(sqrt(rchisq(nsim, rdf)/rdf), each=nfrail)
+bmat <- bmat + bhat
 if (!is.null(debug)) all.equal(bmat, debug$bmat)
 
 clog <- double(nsim)
 Xmat <- scale(as.matrix(simdata[,c('age', 'trt')]), fit1$means, FALSE)
-bmat <- bmat * sqrt(.3)  #the actual bmat used for fits, var=.3
 
 # Part 1, loglik for a set of nearby Cox models
 fix.lp <- Xmat %*% fixef(fit1)
@@ -60,23 +64,21 @@ for (i in 1:nsim) {
 if (!is.null(debug)) aeq(clog, debug$loglik)
 
 # Part 2: Taylor series for the PPL
-bhat <- unlist(fit1$frail)  
-b.sig <- t(bmat-bhat) %*% fit1$hmat[1:nfrail, 1:nfrail]  #b time sqrt(H)
+b.sig <- t(bmat-bhat) %*% hmatbb  #b time sqrt(H)
 taylor <- rowSums(b.sig^2)/2
 
-temp2 <- cbind(clog, fit1$log[3] + colSums(bmat^2)/.6 - taylor)
-# In the coxme code, we center using the Laplace approx IPL (with error), but
-#  fit1 above reports the error corrected one.  So do another call without
-#  refinement to fetch it.
-fit2 <-  coxme(Surv(time, status) ~ age + trt + (trt|inst) + strata(inst),
-              vfixed=.3, simdata)
-
-m2 <- fit2$log[2]
+temp2 <- cbind(clog-colSums(bmat^2)/.6 , fit1$log[3] - taylor)
+m2 <- fit1$log[2]
 errhat <- exp(temp2[,1]-m2) - exp(temp2[,2]-m2)
 
+require(mvtnorm)
+tdens <- dmvt(t(bmat), delta=bhat, sigma=as.matrix(solve(hmatbb)), df=rdf)
+gdens <- -(log(2*pi) + log(.3))*nfrail/2
+
+errhat <- errhat * exp(gdens-tdens)  # account for importance sampling dis
 if (!is.null(debug)) {
     aeq(errhat, debug$errhat)
     }
-
-aeq(c(mean(errhat), sqrt(var(errhat)/nsim)), fit1$refine)
+mtemp <- mean(errhat)
+aeq(c(log(1+ mean(errhat)), sqrt(var(errhat)/nsim)/(1+mtemp)), fit1$refine)
 
